@@ -5,12 +5,11 @@ from abc import ABCMeta, abstractmethod
 from contextlib import suppress
 from io import StringIO
 from pathlib import Path
-from typing import IO, Dict, List
+from typing import IO, Dict, List, Union
 
 import log
 
-from . import settings, types
-
+from . import types, utils
 
 _REGISTRY: Dict[str, type] = {}
 
@@ -44,7 +43,7 @@ class JSON(Formatter):
 
     @classmethod
     def extensions(cls):
-        return {'.json'}
+        return {".json"}
 
     @classmethod
     def deserialize(cls, file_object):
@@ -60,13 +59,13 @@ class TOML(Formatter):
 
     @classmethod
     def extensions(cls):
-        return {'.toml'}
+        return {".toml"}
 
     @classmethod
     def deserialize(cls, file_object):
         import tomlkit
 
-        return tomlkit.loads(file_object.read())
+        return utils.dictify(tomlkit.loads(file_object.read()))
 
     @classmethod
     def serialize(cls, data):
@@ -75,18 +74,18 @@ class TOML(Formatter):
         return tomlkit.dumps(data)
 
 
-class RuamelYAML(Formatter):
+class YAML(Formatter):
     """Formatter for (round-trip) YAML Ain't Markup Language."""
 
     @classmethod
     def extensions(cls):
-        return {'.yml', '.yaml'}
+        return {"", ".yml", ".yaml"}
 
     @classmethod
     def deserialize(cls, file_object):
-        from ruamel.yaml import YAML
+        from ruamel.yaml import YAML as _YAML
 
-        yaml = YAML()
+        yaml = _YAML()
         yaml.preserve_quotes = True  # type: ignore
         try:
             return yaml.load(file_object)
@@ -96,62 +95,30 @@ class RuamelYAML(Formatter):
 
     @classmethod
     def serialize(cls, data):
-        from ruamel.yaml import YAML
+        from ruamel.yaml import YAML as _YAML
 
-        yaml = YAML()
+        yaml = _YAML()
         yaml.register_class(types.List)
         yaml.register_class(types.Dict)
-        if settings.INDENT_YAML_BLOCKS:
-            yaml.indent(mapping=2, sequence=4, offset=2)
+        yaml.indent(mapping=2, sequence=4, offset=2)
 
         stream = StringIO()
         yaml.dump(data, stream)
-        text = stream.getvalue().strip() + '\n'
+        text = stream.getvalue()
+
+        if text.startswith("  "):
+            return text[2:].replace("\n  ", "\n")
 
         if text == "{}\n":
             return ""
 
-        return text.replace('- \n', '-\n')
-
-
-class PyYAML(Formatter):
-    """Formatter for YAML Ain't Markup Language."""
-
-    @classmethod
-    def extensions(cls):
-        return {'.yml', '.yaml'}
-
-    @classmethod
-    def deserialize(cls, file_object):
-        import yaml
-
-        return yaml.safe_load(file_object)
-
-    @classmethod
-    def serialize(cls, data):
-        import yaml
-
-        def represent_none(self, _):
-            return self.represent_scalar('tag:yaml.org,2002:null', '')
-
-        yaml.add_representer(type(None), represent_none)
-
-        class Dumper(yaml.Dumper):
-            def increase_indent(self, flow=False, indentless=False):
-                return super().increase_indent(
-                    flow=flow,
-                    indentless=False if settings.INDENT_YAML_BLOCKS else indentless,
-                )
-
-        text = yaml.dump(data, Dumper=Dumper, sort_keys=False, default_flow_style=False)
-
-        return text
+        return text.replace("- \n", "-\n")
 
 
 def deserialize(path: Path, extension: str, *, formatter=None) -> Dict:
     if formatter is None:
         formatter = _get_formatter(extension)
-    with path.open('r') as file_object:
+    with path.open("r") as file_object:
         data = formatter.deserialize(file_object)
         if data is None:
             log.debug(f"No data in {path}")
@@ -162,16 +129,15 @@ def deserialize(path: Path, extension: str, *, formatter=None) -> Dict:
         return data
 
 
-def serialize(data: Dict, extension: str = '.yml', *, formatter=None) -> str:
+def serialize(
+    data: Union[Dict, List], extension: str = ".yml", *, formatter=None
+) -> str:
     if formatter is None:
         formatter = _get_formatter(extension)
     return formatter.serialize(data)
 
 
 def _get_formatter(extension: str):
-    if settings.YAML_LIBRARY == 'PyYAML':  # pragma: no cover
-        register('.yml', PyYAML)
-
     with suppress(KeyError):
         return _REGISTRY[extension]
 
@@ -179,4 +145,4 @@ def _get_formatter(extension: str):
         if extension in formatter.extensions():
             return formatter
 
-    raise ValueError(f'Unsupported file extension: {extension!r}')
+    raise ValueError(f"Unsupported file extension: {extension!r}")
