@@ -7,30 +7,33 @@ import log
 from . import settings, types
 from .mapper import create_mapper
 
-
-LOAD_BEFORE_METHODS = ['__getattribute__', '__getitem__', '__iter__']
-SAVE_AFTER_METHODS = [
-    '__setattr__',
-    '__setitem__',
-    '__delitem__',
-    'append',
-    'extend',
-    'insert',
-    'remove',
-    'pop',
-    'clear',
-    'sort',
-    'reverse',
-    'popitem',
-    'update',
+LOAD_BEFORE_METHODS = [
+    "__getattribute__",
+    "__getitem__",
+    "__iter__",
 ]
-FLAG = '_patched'
+SAVE_AFTER_METHODS = [
+    "__setattr__",
+    "__setitem__",
+    "__delitem__",
+    "append",
+    "extend",
+    "insert",
+    "remove",
+    "pop",
+    "clear",
+    "sort",
+    "reverse",
+    "popitem",
+    "update",
+]
+FLAG = "_patched"
 
 
 def apply(instance, mapper):
     """Path methods that get or set attributes."""
     cls = instance.__class__
-    log.debug(f'Patching methods on {cls}')
+    log.debug(f"Patching methods on {cls}")
 
     for method_name in LOAD_BEFORE_METHODS:
         with suppress(AttributeError):
@@ -79,20 +82,18 @@ def load_before(cls, method):
 
     @wraps(method)
     def wrapped(self, *args, **kwargs):
-        __tracebackhide__ = settings.HIDE_TRACEBACK_IN_HOOKS
+        __tracebackhide__ = settings.HIDDEN_TRACEBACK
 
         mapper = get_mapper(self)
         if enabled(mapper, args):
             if mapper.exists and mapper.modified:
                 log.debug(f"Loading automatically before '{method.__name__}' call")
                 mapper.load()
-                if mapper.auto_save:
-                    log.debug("Saving automatically after load")
-                    mapper.save(_log=False)
+                mapper.save(_log=False)
 
         return method(self, *args, **kwargs)
 
-    log.debug(f'Patched method to load before call: {cls.__name__}.{method.__name__}')
+    log.debug(f"Patched method to load before call: {cls.__name__}.{method.__name__}")
     setattr(wrapped, FLAG, True)
 
     return wrapped
@@ -106,7 +107,7 @@ def save_after(cls, method):
 
     @wraps(method)
     def wrapped(self, *args, **kwargs):
-        __tracebackhide__ = settings.HIDE_TRACEBACK_IN_HOOKS
+        __tracebackhide__ = settings.HIDDEN_TRACEBACK
 
         mapper = get_mapper(self)
         if enabled(mapper, args):
@@ -119,13 +120,11 @@ def save_after(cls, method):
         if enabled(mapper, args):
             log.debug(f"Saving automatically after '{method.__name__}' call")
             mapper.save()
-            if mapper.auto_load:
-                log.debug("Loading automatically after save")
-                mapper.load(_log=False)
+            mapper.load(_log=False)
 
         return result
 
-    log.debug(f'Patched method to save after call: {cls.__name__}.{method.__name__}')
+    log.debug(f"Patched method to save after call: {cls.__name__}.{method.__name__}")
     setattr(wrapped, FLAG, True)
 
     return wrapped
@@ -133,7 +132,7 @@ def save_after(cls, method):
 
 def get_mapper(obj):
     try:
-        return object.__getattribute__(obj, 'datafile')
+        return object.__getattribute__(obj, "datafile")
     except AttributeError:
         return None
 
@@ -150,16 +149,16 @@ def enabled(mapper, args) -> bool:
         return False
 
     if args and isinstance(args[0], str):
-        if args[0] in {'Meta', 'datafile'}:
+        if args[0] in {"Meta", "datafile"}:
             return False
-        if args[0].startswith('_'):
+        if args[0].startswith("_"):
             return False
 
     return True
 
 
 @contextmanager
-def disabled():
+def disabled(*objects):
     """Globally disable method hooks, temporarily."""
     enabled = settings.HOOKS_ENABLED
     if enabled:
@@ -168,3 +167,7 @@ def disabled():
         yield
     finally:
         settings.HOOKS_ENABLED = enabled
+        if enabled:
+            for o in objects:
+                with suppress(AttributeError):
+                    o.datafile.save()
