@@ -5,6 +5,7 @@ from __future__ import annotations
 import dataclasses
 import inspect
 import os
+from functools import reduce
 from glob import iglob
 from pathlib import Path
 from typing import TYPE_CHECKING, Iterator, Optional
@@ -14,9 +15,7 @@ from parse import parse
 
 from . import hooks
 
-
 if TYPE_CHECKING:
-    from .mapper import Mapper
     from .model import Model
 
 
@@ -26,7 +25,7 @@ Missing = dataclasses._MISSING_TYPE
 
 class Splats:
     def __getattr__(self, name):
-        return '*'
+        return "*"
 
 
 class Manager:
@@ -35,7 +34,8 @@ class Manager:
 
     def get(self, *args, **kwargs) -> Model:
         fields = dataclasses.fields(self.model)
-        missing_args = [Missing] * (len(fields) - len(args) - len(kwargs))
+        required = sum(1 for field in fields if isinstance(field.default, Missing))
+        missing_args = [Missing] * (required - len(args) - len(kwargs))
         args = (*args, *missing_args)
 
         with hooks.disabled():
@@ -61,30 +61,33 @@ class Manager:
             instance.datafile.load()
             return instance
 
-    def all(self, *, _exclude: str = '') -> Iterator[Model]:
-        path = Path(self.model.Meta.datafile_pattern)
-        if path.is_absolute():
-            log.debug(f"Detected absolute pattern: {path}")
-        elif self.model.Meta.datafile_pattern[:2] == './':
-            log.debug(f"Detected relative pattern: {path}")
+    def all(self, *, _exclude: str = "") -> Iterator[Model]:
+        path = Path(self.model.Meta.datafile_pattern).expanduser()
+        if path.is_absolute() or self.model.Meta.datafile_pattern[:2] == "./":
+            log.debug(f"Detected static pattern: {path}")
         else:
             try:
                 root = Path(inspect.getfile(self.model)).parent
-            except TypeError:
-                level = log.DEBUG if '__main__' in str(self.model) else log.WARNING
-                log.log(level, f'Unable to determine module for {self.model}')
+            except (TypeError, OSError):
+                level = log.DEBUG if "__main__" in str(self.model) else log.WARNING
+                log.log(level, f"Unable to determine module for {self.model}")
                 root = Path.cwd()
             path = root / self.model.Meta.datafile_pattern
+            log.debug(f"Detected dynamic pattern: {path}")
 
         pattern = str(path.resolve())
         splatted = pattern.format(self=Splats()).replace(
-            f'{os.sep}*{os.sep}', f'{os.sep}**{os.sep}'
+            f"{os.sep}*{os.sep}", f"{os.sep}**{os.sep}"
         )
 
-        log.info(f'Finding files matching pattern: {splatted}')
+        log.info(f"Finding files matching pattern: {splatted}")
         for index, filename in enumerate(iglob(splatted, recursive=True)):
 
-            log.debug(f'Found matching path {index + 1}: {filename}')
+            if Path(filename).is_dir():
+                log.debug(f"Skipped matching directory {index + 1}: {filename}")
+                continue
+
+            log.debug(f"Found matching path {index + 1}: {filename}")
             result = parse(pattern, filename)
             if result:
                 values = list(result.named.values())
@@ -95,16 +98,17 @@ class Manager:
                     values[-1] = parts[1]
 
                 if _exclude and values[0].startswith(_exclude):
-                    log.debug(f'Skipped loading of excluded value: {values[0]}')
+                    log.debug(f"Skipped loading of excluded value: {values[0]}")
                     continue
 
                 yield self.get(*values)
 
-    def filter(self, *, _exclude: str = '', **query):
+    def filter(self, *, _exclude: str = "", **query):
         for item in self.all(_exclude=_exclude):
             match = True
             for key, value in query.items():
-                if getattr(item, key) != value:
+                # The use of reduce helps to handle nested attribute queries
+                if reduce(getattr, [item] + key.split("__")) != value:  # type: ignore
                     match = False
             if match:
                 yield item
