@@ -2,13 +2,16 @@
 
 from dataclasses import dataclass
 from enum import Enum
-from typing import ByteString, Dict, List, Mapping, Optional, Set
+from typing import ByteString, Dict, List, Mapping, Optional, Set, Union
 
 import pytest
 from ruamel.yaml.scalarstring import LiteralScalarString
+from typing_extensions import TypedDict
 
 from datafiles import converters, settings
 
+from . import xfail_without_pep_604, xfail_without_type_names
+
 
 @dataclass
 class MyDataclass:
@@ -22,6 +25,11 @@ class MyNestedDataclass:
     dc: MyDataclass
 
 
+class MyTypedDict(TypedDict):
+    title: str
+    salary: int
+
+
 class MyNonDataclass:
     pass
 
@@ -43,22 +51,23 @@ IntegerSet = converters.Set.of_type(converters.Integer)
 StringSet = converters.Set.of_type(converters.String)
 MyDataclassConverter = converters.map_type(MyDataclass)
 MyDataclassConverterList = converters.map_type(List[MyDataclass])
+MyTypedDictConverter = converters.map_type(MyTypedDict)
 
 
 def describe_map_type():
     def it_handles_extended_types(expect):
         converter = converters.map_type(converters.Number)
-        expect(converter.__name__) == 'Number'
+        expect(converter.__name__) == "Number"
 
     def it_handles_list_annotations(expect):
         converter = converters.map_type(List[str])
-        expect(converter.__name__) == 'StringList'
+        expect(converter.__name__) == "StringList"
         expect(converter.CONVERTER) == converters.String
 
     def it_handles_list_annotations_of_dataclasses(expect):
         converter = converters.map_type(List[MyDataclass])
-        expect(converter.__name__) == 'MyDataclassConverterList'
-        expect(converter.CONVERTER.__name__) == 'MyDataclassConverter'
+        expect(converter.__name__) == "MyDataclassConverterList"
+        expect(converter.CONVERTER.__name__) == "MyDataclassConverter"
 
     def it_requires_list_annotations_to_have_a_type(expect):
         with expect.raises(TypeError, "Type is required with 'List' annotation"):
@@ -66,13 +75,13 @@ def describe_map_type():
 
     def it_handles_set_annotations(expect):
         converter = converters.map_type(Set[str])
-        expect(converter.__name__) == 'StringSet'
+        expect(converter.__name__) == "StringSet"
         expect(converter.CONVERTER) == converters.String
 
     def it_handles_set_annotations_of_dataclasses(expect):
         converter = converters.map_type(Set[MyDataclass])
-        expect(converter.__name__) == 'MyDataclassConverterSet'
-        expect(converter.CONVERTER.__name__) == 'MyDataclassConverter'
+        expect(converter.__name__) == "MyDataclassConverterSet"
+        expect(converter.CONVERTER.__name__) == "MyDataclassConverter"
 
     def it_requires_set_annotations_to_have_a_type(expect):
         with expect.raises(TypeError, "Type is required with 'Set' annotation"):
@@ -80,42 +89,72 @@ def describe_map_type():
 
     def it_handles_dict_annotations(expect):
         converter = converters.map_type(Dict[str, int])
-        expect(converter.__name__) == 'StringIntegerDict'
+        expect(converter.__name__) == "StringIntegerDict"
 
     def it_requires_dict_annotations_to_have_types(expect):
         with expect.raises(TypeError, "Types are required with 'Dict' annotation"):
             converters.map_type(Dict)
 
+    @xfail_without_type_names
+    def it_handles_typed_dict_annotations(expect):
+        converter = converters.map_type(MyTypedDict)
+        expect(converter.__name__) == "StringAnyDict"
+
     def it_handles_abstract_mapping_types(expect):
         converter = converters.map_type(Mapping[str, int])
-        expect(converter.__name__) == 'StringIntegerDict'
+        expect(converter.__name__) == "StringIntegerDict"
 
     def it_handles_dataclasses(expect):
         converter = converters.map_type(MyDataclass)
-        expect(converter.__name__) == 'MyDataclassConverter'
+        expect(converter.__name__) == "MyDataclassConverter"
         expect(converter.CONVERTERS) == {
-            'foobar': converters.Integer,
-            'flag': converters.Boolean,
+            "foobar": converters.Integer,
+            "flag": converters.Boolean,
         }
 
+    @pytest.mark.parametrize(
+        ("cls", "converter"),
+        [
+            (list, converters.List),
+            (dict, converters.Dictionary),
+        ],
+    )
+    def it_handles_container_literals(expect, cls, converter):
+        expect(converters.map_type(cls)) == converter
+
     def it_handles_enums(expect):
         converter = converters.map_type(Color)
-        expect(converter.__name__) == 'ColorConverter'
+        expect(converter.__name__) == "ColorConverter"
 
+    @xfail_without_pep_604
     def it_handles_optionals(expect):
-        converter = converters.map_type(Optional[str])
-        expect(converter.__name__) == 'OptionalString'
+        converter = converters.map_type(str | None)  # type: ignore
+        expect(converter.__name__) == "OptionalString"
         expect(converter.TYPE) == str
         expect(converter.DEFAULT).is_(None)
 
+    def it_handles_optionals_with_legacy_syntax(expect):
+        converter = converters.map_type(Optional[str])
+        expect(converter.__name__) == "OptionalString"
+        expect(converter.TYPE) == str
+        expect(converter.DEFAULT).is_(None)
+
+    def it_handles_unions_with_strings(expect):
+        converter = converters.map_type(Union[int, str])
+        expect(converter.TYPE) == str
+
+    def it_handles_unions_with_numbers(expect):
+        converter = converters.map_type(Union[int, float])
+        expect(converter.TYPE) == float
+
     def it_handles_string_type_annotations(expect):
-        converter = converters.map_type('float')
+        converter = converters.map_type("float")
         expect(converter.TYPE) == float
 
     def it_handles_string_type_annotations_for_extensions(expect):
-        converter = converters.map_type('Number')
+        converter = converters.map_type("Number")
         expect(converter.TYPE) == float
-        expect(converter.__name__) == 'Number'
+        expect(converter.__name__) == "Number"
 
     def it_rejects_unknown_types(expect):
         with expect.raises(
@@ -139,41 +178,41 @@ def describe_map_type():
 def describe_converter():
     def describe_to_python_value():
         @pytest.mark.parametrize(
-            'converter, data, value',
+            "converter, data, value",
             [
-                (converters.Boolean, '1', True),
-                (converters.Boolean, '0', False),
-                (converters.Boolean, 'enabled', True),
-                (converters.Boolean, 'disabled', False),
-                (converters.Boolean, 'T', True),
-                (converters.Boolean, 'F', False),
-                (converters.Boolean, 'true', True),
-                (converters.Boolean, 'false', False),
-                (converters.Boolean, 'Y', True),
-                (converters.Boolean, 'N', False),
-                (converters.Boolean, 'yes', True),
-                (converters.Boolean, 'no', False),
-                (converters.Boolean, 'on', True),
-                (converters.Boolean, 'off', False),
+                (converters.Boolean, "1", True),
+                (converters.Boolean, "0", False),
+                (converters.Boolean, "enabled", True),
+                (converters.Boolean, "disabled", False),
+                (converters.Boolean, "T", True),
+                (converters.Boolean, "F", False),
+                (converters.Boolean, "true", True),
+                (converters.Boolean, "false", False),
+                (converters.Boolean, "Y", True),
+                (converters.Boolean, "N", False),
+                (converters.Boolean, "yes", True),
+                (converters.Boolean, "no", False),
+                (converters.Boolean, "on", True),
+                (converters.Boolean, "off", False),
                 (converters.Boolean, 0, False),
                 (converters.Boolean, 1, True),
                 (converters.Float, 4, 4.0),
                 (converters.Integer, 4.2, 4),
-                (converters.String, 4.2, '4.2'),
-                (converters.String, 42, '42'),
-                (converters.String, True, 'True'),
-                (converters.String, False, 'False'),
+                (converters.String, 4.2, "4.2"),
+                (converters.String, 42, "42"),
+                (converters.String, True, "True"),
+                (converters.String, False, "False"),
             ],
         )
         def when_immutable(expect, converter, data, value):
             expect(converter.to_python_value(data)) == value
 
         @pytest.mark.parametrize(
-            'converter, data, value',
+            "converter, data, value",
             [
                 (IntegerList, [], []),
-                (IntegerList, '1, 2.3', [1, 2]),
-                (IntegerList, '42', [42]),
+                (IntegerList, "1, 2.3", [1, 2]),
+                (IntegerList, "42", [42]),
                 (IntegerList, 42, [42]),
                 (IntegerList, None, []),
                 (IntegerList, [42], [42]),
@@ -181,10 +220,10 @@ def describe_converter():
                 (IntegerList, [None, None], []),
                 (MyDict, None, {}),
                 (MyDict, {}, {}),
-                (MyDict, {'a': 1}, {'a': 1}),
+                (MyDict, {"a": 1}, {"a": 1}),
                 (IntegerSet, set(), set()),
-                (IntegerSet, '1, 1.1, 1.9, 2.3, 3', {1, 2, 3}),
-                (IntegerSet, '42', {42}),
+                (IntegerSet, "1, 1.1, 1.9, 2.3, 3", {1, 2, 3}),
+                (IntegerSet, "42", {42}),
                 (IntegerSet, 42, {42}),
                 (IntegerSet, None, set()),
                 (IntegerSet, [None], set()),
@@ -192,6 +231,9 @@ def describe_converter():
                 (MyDataclassConverter, MyDataclass(42), MyDataclass(foobar=42)),
                 (MyDataclassConverterList, None, []),
                 (MyDataclassConverterList, 42, [MyDataclass(foobar=0)]),
+                (MyTypedDictConverter, None, {}),
+                (MyTypedDictConverter, {}, {}),
+                (MyTypedDictConverter, {"a": 1}, {"a": 1}),
             ],
         )
         def when_mutable(expect, converter, data, value):
@@ -221,72 +263,76 @@ def describe_converter():
         def when_invalid(expect):
             message = "invalid literal for int() with base 10: 'a'"
             with expect.raises(ValueError, message):
-                converters.Integer.to_python_value('a')
+                converters.Integer.to_python_value("a")
 
         def when_list_of_dataclasses(expect):
             converter = converters.map_type(List[MyDataclass])
 
-            data = [{'foobar': 1}, {'foobar': 2}, {'foobar': 3}]
+            data = [{"foobar": 1}, {"foobar": 2}, {"foobar": 3}]
             value = [MyDataclass(1), MyDataclass(2), MyDataclass(3)]
 
             expect(converter.to_python_value(data, target_object=None)) == value
 
         def with_existing_list(expect):
-            orginal = [1, 2]
+            original = [1, 2]
 
-            value = IntegerList.to_python_value("3, 4", target_object=orginal)
+            value = IntegerList.to_python_value("3, 4", target_object=original)
 
             expect(value) == [3, 4]
-            expect(id(value)) == id(orginal)
+            expect(id(value)) == id(original)
 
         def when_existing_dict(expect):
-            orginal = {'a': 1}
+            original = {"a": 1}
 
-            value = MyDict.to_python_value({'b': 2}, target_object=orginal)
+            value = MyDict.to_python_value({"b": 2}, target_object=original)
 
-            expect(value) == {'b': 2}
-            expect(id(value)) == id(orginal)
+            expect(value) == {"b": 2}
+            expect(id(value)) == id(original)
 
         def with_existing_dataclass(expect):
-            orginal = MyDataclass(foobar=1)
+            original = MyDataclass(foobar=1)
 
             value = MyDataclassConverter.to_python_value(
-                {'foobar': 2}, target_object=orginal
+                {"foobar": 2}, target_object=original
             )
 
             expect(value) == MyDataclass(foobar=2)
-            expect(id(value)) == id(orginal)
+            expect(id(value)) == id(original)
 
     def describe_to_preserialization_data():
         @pytest.mark.parametrize(
-            'converter, value, data',
+            "converter, value, data",
             [
                 # Builtins
                 (converters.Boolean, None, False),
                 (converters.Float, None, 0.0),
                 (converters.Integer, None, 0),
-                (converters.String, None, ''),
+                (converters.String, None, ""),
                 # Lists
-                (StringList, 'ab', ['ab']),
-                (StringList, ('b', 1, 'A'), ['b', '1', 'A']),
-                (StringList, {'b', 1, 'A'}, ['1', 'A', 'b']),
-                (StringList, 42, ['42']),
-                (StringList, [123, True, False], ['123', 'True', 'False']),
+                (StringList, "ab", ["ab"]),
+                (StringList, ("b", 1, "A"), ["b", "1", "A"]),
+                (StringList, {"b", 1, "A"}, ["1", "A", "b"]),
+                (StringList, 42, ["42"]),
+                (StringList, [123, True, False], ["123", "True", "False"]),
                 (StringList, [], [None]),
                 (StringList, None, [None]),
+                # Dicts
+                (MyTypedDictConverter, None, {}),
+                (MyTypedDictConverter, {}, {}),
+                (MyTypedDictConverter, {"a": 1}, {"a": 1}),
                 # Sets
-                (StringSet, 'ab', ['ab']),
-                (StringSet, ('b', 1, 'A'), ['b', '1', 'A']),
-                (StringSet, {'b', 1, 'A'}, ['1', 'A', 'b']),
-                (StringSet, 42, ['42']),
-                (StringSet, [123, True, False], ['123', 'True', 'False']),
+                (StringSet, "ab", ["ab"]),
+                (StringSet, ("b", 1, "A"), ["b", "1", "A"]),
+                (StringSet, {"b", 1, "A"}, ["1", "A", "b"]),
+                (StringSet, 42, ["42"]),
+                (StringSet, [123, True, False], ["123", "True", "False"]),
                 (StringSet, [], [None]),
                 (StringSet, None, [None]),
                 # Dataclasses
-                (MyDataclassConverter, None, {'foobar': 0, 'flag': False}),
-                (MyDataclassConverter, {'foobar': 42}, {'foobar': 42, 'flag': False}),
+                (MyDataclassConverter, None, {"foobar": 0, "flag": False}),
+                (MyDataclassConverter, {"foobar": 42}, {"foobar": 42, "flag": False}),
                 (MyDataclassConverterList, None, [None]),
-                (MyDataclassConverterList, 42, [{'foobar': 0, 'flag': False}]),
+                (MyDataclassConverterList, 42, [{"foobar": 0, "flag": False}]),
             ],
         )
         def when_nominal(expect, converter, value, data):
@@ -315,16 +361,16 @@ def describe_converter():
         def when_invalid(expect):
             message = "invalid literal for int() with base 10: 'a'"
             with expect.raises(ValueError, message):
-                converters.Integer.to_preserialization_data('a')
+                converters.Integer.to_preserialization_data("a")
 
         def when_list_of_dataclasses(expect):
             converter = converters.map_type(List[MyDataclass])
 
             value = [MyDataclass(1), MyDataclass(2), MyDataclass(3)]
             data = [
-                {'foobar': 1, 'flag': False},
-                {'foobar': 2, 'flag': False},
-                {'foobar': 3, 'flag': False},
+                {"foobar": 1, "flag": False},
+                {"foobar": 2, "flag": False},
+                {"foobar": 3, "flag": False},
             ]
 
             expect(converter.to_preserialization_data(value)) == data
@@ -345,11 +391,11 @@ def describe_converter():
             expect(data) == [2]
 
         def when_dict_with_default(expect):
-            data = MyDict.to_preserialization_data({'a': 1}, default_to_skip={'a': 1})
+            data = MyDict.to_preserialization_data({"a": 1}, default_to_skip={"a": 1})
             expect(data) == {}
 
-            data = MyDict.to_preserialization_data({'b': 2}, default_to_skip={'a': 1})
-            expect(data) == {'b': 2}
+            data = MyDict.to_preserialization_data({"b": 2}, default_to_skip={"a": 1})
+            expect(data) == {"b": 2}
 
         def when_dataclass_with_default(expect):
             data = MyDataclassConverter.to_preserialization_data(
@@ -360,20 +406,20 @@ def describe_converter():
             data = MyDataclassConverter.to_preserialization_data(
                 MyDataclass(2), default_to_skip=MyDataclass(1)
             )
-            expect(data) == {'foobar': 2}
+            expect(data) == {"foobar": 2}
 
             data = MyDataclassConverter.to_preserialization_data(
                 MyDataclass(1, flag=True), default_to_skip=MyDataclass(1)
             )
-            expect(data) == {'flag': True}
+            expect(data) == {"flag": True}
 
         def when_empty_list_and_diff_minimization_disabled(expect, monkeypatch):
-            monkeypatch.setattr(settings, 'MINIMIZE_LIST_DIFFS', False)
+            monkeypatch.setattr(settings, "MINIMAL_DIFFS", False)
             data = StringList.to_preserialization_data([])
             expect(data) == []
 
         def when_empty_set_and_diff_minimization_disabled(expect, monkeypatch):
-            monkeypatch.setattr(settings, 'MINIMIZE_LIST_DIFFS', False)
+            monkeypatch.setattr(settings, "MINIMAL_DIFFS", False)
             data = StringSet.to_preserialization_data([])
             expect(data) == []
 
